import uuid

from sqlalchemy import Column, DateTime, ForeignKey, Unicode, text
from sqlalchemy.dialects.postgresql import UUID
from sqlalchemy.orm import relationship

from .meta import Base


class Case(Base):
    __tablename__ = "cases"

    id = Column(
        "id", UUID(as_uuid=True), primary_key=True, server_default=text("gen_random_uuid()"), default=uuid.uuid4
    )
    office_file_number = Column("office_file_number", Unicode(255), nullable=False, unique=True)
    court_case_number = Column("court_case_number", Unicode(255), nullable=False, unique=True)
    year = Column("year", Unicode(255), nullable=False, unique=True)
    title = Column("title", Unicode(255), nullable=False, unique=True)
    docket_number = Column("docket_number", Unicode(255), nullable=False, unique=True)
    receipt_date = Column("receipt_date", DateTime, nullable=False, index=True)
    limitation_date = Column("limitation_date", DateTime, nullable=False, index=True)
    filing_date = Column("filing_date", DateTime, nullable=False, index=True)
    appear_on_behalf_of = Column("appear_on_behalf_of", Unicode(255), nullable=False, unique=True)
    question_of_law = Column("question_of_law", Unicode(255), nullable=False, unique=True)
    aor_name = Column("aor_name", Unicode(255), nullable=False, unique=True)
    opposing_council_aor = Column("opposing_council_aor", Unicode(255), nullable=False, unique=True)
    opposing_council_detail = Column("opposing_council_detail", Unicode(255), nullable=False)
    lower_court_case_number = Column("lower_court_case_number", Unicode(255), nullable=False, unique=True)
    date_of_impugned_judgement = Column("date_of_impugned_judgement", DateTime, nullable=False, index=True)
    brief_description = Column("brief_description", Unicode(255), nullable=False, unique=True)
    remarks = Column("remarks", Unicode(255), nullable=False, unique=True)
    slp_counter = Column("slp_counter", Unicode(255), nullable=False, unique=True)
    contact_detail = Column("contact_detail", Unicode(255), nullable=False, unique=True)
    case_connected_with = Column("case_connected_with", Unicode(255), nullable=False, unique=True)
    bunch_cases = Column("bunch_cases", Unicode(255), nullable=False)

    court_id = Column("court_id", UUID(as_uuid=True), ForeignKey("courts.id"), nullable=True)
    department_id = Column("department_id", UUID(as_uuid=True), ForeignKey("departments.id"), nullable=False)
    office_id = Column("office_id", UUID(as_uuid=True), ForeignKey("offices.id"), nullable=False)
    case_type_id = Column("case_type_id", UUID(as_uuid=True), ForeignKey("case_types.id"), nullable=True)
    act_id = Column("act_id", UUID(as_uuid=True), ForeignKey("acts.id"), nullable=True)
    nature_id = Column("nature_id", UUID(as_uuid=True), ForeignKey("natures.id"), nullable=False)
    office_status_id = Column(
        "office_status_id", UUID(as_uuid=True), ForeignKey("office_statuses.id"), nullable=False
    )  # Old Name Latest Status
    court_status_id = Column(
        "court_status_id", UUID(as_uuid=True), ForeignKey("court_statuses.id"), nullable=True
    )  # Old Name Status In Court

    court = relationship("Court", backref="cases")
    department = relationship("Department", backref="cases")
    office = relationship("Office", backref="cases")
    case_type = relationship("CaseType", backref="cases")
    act = relationship("Act", backref="cases")
    nature = relationship("Nature", backref="cases")
    office_status = relationship("OfficeStatus")
    court_status = relationship("CourtStatus", back_populates="cases")

    def __init__(
        self,
        date,
        pax,
        bill_id,
        kot_id,
        food_table_id,
        customer_id,
        voucher_type,
        user_id,
    ):
        self.date = date
        self.pax = pax
        self.creation_date = date
        self.last_edit_date = date
        self.bill_id = bill_id
        self.kot_id = kot_id
        self.food_table_id = food_table_id
        self.customer_id = customer_id
        self.narration = None
        self.voucher_type = voucher_type
        self.user_id = user_id
