import uuid

from sqlalchemy import (
    Column,
    DateTime,
    ForeignKey,
    Unicode,
    text,
)
from sqlalchemy.dialects.postgresql import UUID
from sqlalchemy.orm import relationship

from .meta import Base


class Hearing(Base):
    __tablename__ = "hearings"

    id = Column(
        "id", UUID(as_uuid=True), primary_key=True, server_default=text("gen_random_uuid()"), default=uuid.uuid4
    )
    case_id = Column(
        "case_id",
        UUID(as_uuid=True),
        ForeignKey("cases.id"),
        nullable=False,
        index=True,
    )
    judges = Column("judges", Unicode(255), nullable=False, unique=True)
    brief = Column("brief", Unicode(255), nullable=False, unique=True)
    next_hearing_date = Column("next_hearing_date", DateTime, nullable=False, index=True)
    court_status_id = Column("court_status_id", UUID(as_uuid=True), ForeignKey("court_statuses.id"), nullable=True)
    court_number = Column("court_number", Unicode(255), nullable=False, unique=True)
    item_number = Column("item_number", Unicode(255), nullable=False, unique=True)

    court_status = relationship("CourtStatus", back_populates="hearings")

    def __init__(
        self,
        voucher_id=None,
        code=None,
        food_table_id=None,
        date=None,
        user_id=None,
        id_=None,
    ):
        self.id = id_
        self.voucher_id = voucher_id
        self.code = code
        self.food_table_id = food_table_id
        self.date = date
        self.user_id = user_id
