import uuid

from datetime import date
from typing import Optional

from .act import ActLink
from .case_type import CaseTypeLink
from .court import CourtLink
from .court_status import CourtStatusLink
from .department import DepartmentLink
from .nature import NatureLink
from .office import OfficeLink
from .office_status import OfficeStatusLink
from pydantic import BaseModel, Field

from . import to_camel


class CaseIn(BaseModel):
    office_file_number: str
    court_case_number: str
    year: str
    title: str
    docket_number: str
    receipt_date: date
    limitation_date: date
    filing_date: date
    appear_on_behalf_of: str
    question_of_law: str
    aor_name: str
    opposing_council_aor: str
    opposing_council_detail: str
    lower_court_case_number: str
    date_of_impugned_judgement: date
    brief_description: str
    remarks: str
    slp_counter: str
    contact_detail: str
    case_connected_with: str
    bunch_cases: str

    court = CourtLink
    department = DepartmentLink
    office = OfficeLink
    case_type = CaseTypeLink
    act = ActLink
    nature = NatureLink
    office_status = OfficeStatusLink
    court_status = CourtStatusLink

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class Case(CaseIn):
    id_: uuid.UUID

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class CaseBlank(CaseIn):
    court = [CourtLink]
    department = [DepartmentLink]
    office = [OfficeLink]
    case_type = [CaseTypeLink]
    act = [ActLink]
    nature = [NatureLink]
    office_status = [OfficeStatusLink]
    court_status = [CourtStatusLink]

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class CaseLink(BaseModel):
    id_: uuid.UUID = Field(...)
    name: Optional[str]

    class Config:
        fields = {"id_": "id"}
