import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/internal/Observable';
import { catchError } from 'rxjs/operators';

import { ErrorLoggerService } from '../core/error-logger.service';
import { Case } from '../core/case';

const httpOptions = {
  headers: new HttpHeaders({ 'Content-Type': 'application/json' }),
};
const url = '/api/cases';
const serviceName = 'CaseService';

@Injectable({
  providedIn: 'root',
})
export class CaseService {
  constructor(private http: HttpClient, private log: ErrorLoggerService) {}

  get(id: string | null): Observable<Case> {
    const getUrl: string = id === null ? url : `${url}/${id}`;
    return this.http
      .get<Case>(getUrl)
      .pipe(catchError(this.log.handleError(serviceName, `get id=${id}`))) as Observable<Case>;
  }

  list(): Observable<Case[]> {
    return this.http
      .get<Case[]>(`${url}/list`)
      .pipe(catchError(this.log.handleError(serviceName, 'list'))) as Observable<Case[]>;
  }

  save(case: Case): Observable<Case> {
    return this.http
      .post<Case>(url, case, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'save'))) as Observable<Case>;
  }

  update(case: Case): Observable<Case> {
    return this.http
      .put<Case>(`${url}/${case.id}`, case, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'update'))) as Observable<Case>;
  }

  saveOrUpdate(case: Case): Observable<Case> {
    if (!case.id) {
      return this.save(case);
    }
    return this.update(case);
  }

  delete(id: string): Observable<Case> {
    return this.http
      .delete<Case>(`${url}/${id}`, httpOptions)
      .pipe(catchError(this.log.handleError(serviceName, 'delete'))) as Observable<Case>;
  }
}
