import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { DepartmentListResolver } from '../departments/department-list-resolver.service';

import { CaseDetailComponent } from './case-detail/case-detail.component';
import { CaseListResolver } from './case-list-resolver.service';
import { CaseListComponent } from './case-list/case-list.component';
import { CaseResolver } from './case-resolver.service';

const advocatesRoutes: Routes = [
  {
    path: '',
    component: CaseListComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Cases',
    },
    resolve: {
      list: CaseListResolver,
    },
  },
  {
    path: 'new',
    component: CaseDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Cases',
    },
    resolve: {
      item: CaseResolver,
      departments: DepartmentListResolver,
    },
  },
  {
    path: ':id',
    component: CaseDetailComponent,
    canActivate: [AuthGuard],
    data: {
      permission: 'Cases',
    },
    resolve: {
      item: CaseResolver,
      departments: DepartmentListResolver,
    },
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(advocatesRoutes)],
  exports: [RouterModule],
  providers: [CaseListResolver, CaseResolver],
})
export class CasesRoutingModule {}
